Documentation
¶
Index ¶
- func Box(title string, content string)
- func ClearScreen()
- func Confirm(prompt string, defaultYes bool) bool
- func ConfirmWithBubbles(opts ConfirmOptions) bool
- func Error(text string)
- func Header(text string)
- func HeaderBold(text string)
- func HeaderGradient(text string)
- func HeaderMinimal(text string)
- func Info(text string)
- func List(items []string, header string)
- func ServiceStatus(name string, status string, port int, latency string)
- func Spin(title string, command string, args ...string) error
- func SpinWithBubbles(message string, command string, args ...string) error
- func Style(text string, opts ...string)
- func Success(text string)
- func Table(headers []string, rows [][]string)
- func Warning(text string)
- type ConfirmOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ClearScreen ¶
func ClearScreen()
ClearScreen clears the terminal screen without flickering Uses ANSI escape codes to move cursor to top instead of full clear
func Confirm ¶
Confirm shows a simple confirmation prompt (keeping backwards compatibility) Now uses Bubble Tea instead of Gum
func ConfirmWithBubbles ¶
func ConfirmWithBubbles(opts ConfirmOptions) bool
ConfirmWithBubbles shows a Bubble Tea confirmation prompt Uses Huh for a native Bubble Tea experience without external dependencies
func HeaderGradient ¶
func HeaderGradient(text string)
HeaderGradient renders a header with multi-color gradient effect
func HeaderMinimal ¶
func HeaderMinimal(text string)
HeaderMinimal renders a clean header with top/bottom borders only
func ServiceStatus ¶
ServiceStatus renders a service status line
func SpinWithBubbles ¶
SpinWithBubbles runs a command with a beautiful Bubbles spinner Falls back to Gum if no TTY is available
Types ¶
Click to show internal directories.
Click to hide internal directories.